@@ -32,8 +32,7 @@ public:
 	LDBLE *Get_dx_moles_address(void) {return &dx_moles;}
 	LDBLE *Get_dh2o_moles_address(void) {return &dh2o_moles;}
 	LDBLE *Get_drelated_moles_address(void) {return &drelated_moles;}
-
-
+	
 protected:
 	LDBLE g_moles;
 	LDBLE dg_g_moles;			/* g_moles*dgterm */
@@ -54,6 +53,9 @@ public:
 	void Set_dg(LDBLE t) {dg = t;}
 	LDBLE Get_psi_to_z(void) const {return psi_to_z;}
 	void Set_psi_to_z(LDBLE t) {psi_to_z = t;}
+	void Serialize(Dictionary & dictionary, std::vector < int >&ints, std::vector < double >&doubles);
+	void Deserialize(Dictionary & dictionary, std::vector < int >&ints, std::vector < double >&doubles, int &ii, int &dd);
+	
 protected:
 	LDBLE g;
 	LDBLE dg;
@@ -104,6 +106,8 @@ public:
 	std::map<LDBLE, cxxSurfDL> &Get_g_map(void) {return g_map;}
 	void Set_g_map(std::map<LDBLE, cxxSurfDL> & t) {g_map = t;}
 	std::map<int, double> & Get_dl_species_map(void)       {return this->dl_species_map;}
+	void Serialize(Dictionary & dictionary, std::vector < int >&ints, std::vector < double >&doubles);
+	void Deserialize(Dictionary & dictionary, std::vector < int >&ints, std::vector < double >&doubles, int &ii, int &dd);
 
 protected:
 	std::string name;
